;Project Lynxmotion Quad
;Description: Quad, configuration file.
;		All Hardware connections (excl controls) and body dimensions 
;		are configurated in this file. Can be used with Quad V1.0 and above
;Configuration version: V1.1
;Based on Phoenix code V2.1
;Date: November 29, 2012
;Programmer: Jeroen Janssen (aka Xan)
;
;Hardware setup: ABB2 with ATOM 28 Pro, SSC32 V2, (See further for connections)
;
;NEW IN V1.1
;   - Added speaker constant
;	- Added support for different leg lengths
;	- Optional 4DOF
;	- Optional Safety shut down when voltage drops
;
;--------------------------------------------------------------------
;[CONDITIONAL COMPILING] - COMMENT IF NOT WANTED
;c4DOF			 con 1	 	; Switch between 3DOF and 4DOF
;cTurnOffVol	 con 630 	; When uncomment the bot will turn off when 
							; the voltage drops below this setpoint (630 = 6.3V)
;--------------------------------------------------------------------
;[SERIAL CONNECTIONS]
cSSC_OUT   	con P11		;Output pin for (SSC32 RX) on BotBoard (Yellow)
cSSC_IN    	con P10		;Input pin for (SSC32 TX) on BotBoard (Blue)
cSSC_BAUD 	con i115200	;SSC32 BAUD rate
;--------------------------------------------------------------------
;[BB2 PIN NUMBERS]
cEyesPin		con P8
;--------------------------------------------------------------------
cSpeakerPin		con P9
cVoltagePin		con 17		; Defines the analog input to read the voltage
							; for safety shutdown. (16=AX0=VS, 17=AX1=VL) 
;--------------------------------------------------------------------
;[SSC PIN NUMBERS]
cRRCoxaPin 		con P0	;Rear Right leg Hip Horizontal
cRRFemurPin 	con P1	;Rear Right leg Hip Vertical
cRRTibiaPin  	con P2	;Rear Right leg Knee

cRFCoxaPin 		con P4	;Front Right leg Hip Horizontal
cRFFemurPin 	con P5	;Front Right leg Hip Vertical
cRFTibiaPin  	con P6	;Front Right leg Knee

cLRCoxaPin 		con P16	;Rear Left leg Hip Horizontal
cLRFemurPin 	con P17	;Rear Left leg Hip Vertical
cLRTibiaPin  	con P18	;Rear Left leg Knee

cLFCoxaPin 		con P20	;Front Left leg Hip Horizontal
cLFFemurPin 	con P21	;Front Left leg Hip Vertical
cLFTibiaPin  	con P22	;Front Left leg Knee

#ifdef c4DOF ;Optional tars for 4DOF
  cRRTarsPin	con P3	;Right Rear leg Tars
  cRFTarsPin	con P11	;Right Front leg Tars
  cLRTarsPin	con P19	;Left Rear leg Tars
  cLFTarsPin	con P27	;Left Front leg Tars
#endif
;--------------------------------------------------------------------
;[MIN/MAX ANGLES]
cRRCoxaMin1		con -630	;Mechanical limits of the Right Rear Leg, decimals = 1
cRRCoxaMax1		con 740
cRRFemurMin1	con -900
cRRFemurMax1	con 420
cRRTibiaMin1	con -430
cRRTibiaMax1	con 900

cRFCoxaMin1		con -940	;Mechanical limits of the Right Front Leg, decimals = 1
cRFCoxaMax1		con 500
cRFFemurMin1	con -880
cRFFemurMax1	con 430
cRFTibiaMin1	con -440
cRFTibiaMax1	con 900

cLRCoxaMin1		con -630	;Mechanical limits of the Left Rear Leg, decimals = 1
cLRCoxaMax1		con 740
cLRFemurMin1	con -900
cLRFemurMax1	con 420
cLRTibiaMin1	con -430
cLRTibiaMax1	con 990

cLFCoxaMin1		con -940	;Mechanical limits of the Left Front Leg, decimals = 1
cLFCoxaMax1		con 500
cLFFemurMin1	con -880
cLFFemurMax1	con 430
cLFTibiaMin1	con -440
cLFTibiaMax1	con 900

#ifdef c4DOF ;Optional tars for 4DOF
  cRRTarsMin1	con -1300
  cRRTarsMax1	con 500
  
  cRFTarsMin1	con -1300
  cRFTarsMax1	con 500
  
  cLRTarsMin1	con -1300
  cLRTarsMax1	con 500
  
  cLFTarsMin1	con -1300
  cLFTarsMax1	con 500
#endif
;--------------------------------------------------------------------
;[LEG DIMENSIONS]
;Universal dimensions for each leg
cXXCoxaLength  	con 29		;Length of the Coxa [mm]
cXXFemurLength 	con 56		;Length of the Femur [mm]
cXXTibiaLength 	con 122		;Length of the Tibia [mm]

cRRCoxaLength   con cXXCoxaLength	;Rigth Rear leg
cRRFemurLength  con cXXFemurLength
cRRTibiaLength  con cXXTibiaLength

cRFCoxaLength   con cXXCoxaLength	;Rigth front leg
cRFFemurLength  con cXXFemurLength
cRFTibiaLength  con cXXTibiaLength

cLRCoxaLength   con cXXCoxaLength	;Left Rear leg
cLRFemurLength  con cXXFemurLength
cLRTibiaLength  con cXXTibiaLength

cLFCoxaLength   con cXXCoxaLength	;Left front leg
cLFFemurLength  con cXXFemurLength
cLFTibiaLength  con cXXTibiaLength

#ifdef c4DOF
  cXXTarsLength con 85		;Length of the Tars [mm]

  cRRTarsLength  con cXXTarsLength
  cRFTarsLength  con cXXTarsLength
  cLRTarsLength  con cXXTarsLength
  cLFTarsLength  con cXXTarsLength
#endif
;--------------------------------------------------------------------
;[BODY DIMENSIONS]
cRRCoxaAngle1 	con 0	;Default Coxa setup angle, decimals = 1
cRFCoxaAngle1 	con 0	;Default Coxa setup angle, decimals = 1
cLRCoxaAngle1 	con 0	;Default Coxa setup angle, decimals = 1
cLFCoxaAngle1 	con 0	;Default Coxa setup angle, decimals = 1

cRFOffsetX con -57		;Distance X from center of the body to the Right Front coxa
cRFOffsetZ con -80		;Distance Z from center of the body to the Right Front coxa
cRROffsetX con -57		;Distance X from center of the body to the Right Rear coxa
cRROffsetZ con 80		;Distance Z from center of the body to the Right Rear coxa

cLFOffsetX con 57		;Distance X from center of the body to the Left Front coxa
cLFOffsetZ con -80		;Distance Z from center of the body to the Left Front coxa
cLROffsetX con 57		;Distance X from center of the body to the Left Rear coxa
cLROffsetZ con 80		;Distance Z from center of the body to the Left Rear coxa
;--------------------------------------------------------------------
;[START POSITIONS FEET]
cRRInitPosX con 90		;Start positions of the Right Rear leg
cRRInitPosY con 50
cRRInitPosZ con 60

cRFInitPosX con 90		;Start positions of the Right Front leg
cRFInitPosY con 50
cRFInitPosZ con -60

cLRInitPosX con 90		;Start positions of the Left Rear leg
cLRInitPosY con 50
cLRInitPosZ con 60

cLFInitPosX con 90		;Start positions of the Left Front leg
cLFInitPosY con 50
cLFInitPosZ con -60
;--------------------------------------------------------------------
;[Tars factors used in formula to calc Tarsus angle relative to the ground]
#ifdef c4DOF
  cTarsConst	con	720	;4DOF ONLY
  cTarsMulti	con 2	;4DOF ONLY
  cTarsFactorA	con 70	;4DOF ONLY
  cTarsFactorB	con 60	;4DOF ONLY
  cTarsFactorC	con 50	;4DOF ONLY
#endif
;--------------------------------------------------------------------
